==> wikitty-api-3.3-test-sources.jar: org/nuiton/wikitty/entities/BusinessEntityImplTest.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: BusinessEntityImplTest.java 1136 2011-08-12 14:24:03Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.3/wikitty-api/src/test/java/org/nuiton/wikitty/entities/BusinessEntityImplTest.java $
 * %%
 * Copyright (C) 2009 - 2010 CodeLutin, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.entities;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Assert;
import org.junit.Test;

/**
 *
 * @author poussin
 * @version $Revision: 1136 $
 *
 * Last update: $Date: 2011-08-12 16:24:03 +0200 (Fri, 12 Aug 2011) $
 * by : $Author: tchemit $
 */
public class BusinessEntityImplTest {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(BusinessEntityImplTest.class);

    @Test
    public void testCopyFrom() throws Exception {
        WikittyLabel source = new WikittyLabelImpl();
        source.addLabels("1erLabel");
        source.addLabels("2emeLabel");

        WikittyLabel dest = new WikittyLabelImpl();

        dest.copyFrom(source);
        Assert.assertFalse(source.getWikittyId().equals(dest.getWikittyId()));
        Assert.assertEquals(source.getWikittyVersion(), dest.getWikittyVersion());
        Assert.assertEquals(source.getLabels(), dest.getLabels());
    }
    
}

==> wikitty-api-3.4-test-sources.jar: org/nuiton/wikitty/entities/BusinessEntityImplTest.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: BusinessEntityImplTest.java 1348 2012-01-20 14:08:37Z echatellier $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.4/wikitty-api/src/test/java/org/nuiton/wikitty/entities/BusinessEntityImplTest.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.entities;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Assert;
import org.junit.Test;

/**
 *
 * @author poussin
 * @version $Revision: 1348 $
 *
 * Last update: $Date: 2012-01-20 15:08:37 +0100 (ven, 20 jan 2012) $
 * by : $Author: echatellier $
 */
public class BusinessEntityImplTest {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(BusinessEntityImplTest.class);

    @Test
    public void testCopyFrom() throws Exception {
        WikittyLabel source = new WikittyLabelImpl();
        source.addLabels("1erLabel");
        source.addLabels("2emeLabel");

        WikittyLabel dest = new WikittyLabelImpl();

        dest.copyFrom(source);
        Assert.assertFalse(source.getWikittyId().equals(dest.getWikittyId()));
        Assert.assertEquals(source.getWikittyVersion(), dest.getWikittyVersion());
        Assert.assertEquals(source.getLabels(), dest.getLabels());
    }
    
}
